@@ -13,7 +13,7 @@ DEFAULT_DB_ENV_VARS: Sequence[str] = (
 ASYNC_DRIVER_HINT = re.compile(r"\+(?:async|asyncpg|aiosqlite|aiomysql|asyncmy|aio\w+)")
 
 # Alembic templates loaded from package resources (svc_infra.db.templates.setup)
-# Kept as module-level constants for compatibility with setup.py
+# Kept as module-level constants for compatibility with core.py
 try:
     import importlib.resources as pkg
 
@@ -23,8 +23,8 @@ try:
 except Exception:
     # Fallbacks (should not normally happen). Provide minimal safe defaults.
     ALEMBIC_INI_TEMPLATE = """[alembic]\nscript_location = {script_location}\nsqlalchemy.url = {sqlalchemy_url}\n"""
-    ALEMBIC_SCRIPT_TEMPLATE = '"""${message}"""\nfrom alembic import op\nimport sqlalchemy as sa\n\nrevision = ${repr(up_revision)}\ndown_revision = ${repr(down_revision)}\nbranch_labels = ${repr(branch_labels)}\ndepends_on = ${repr(depends_on)}\n\ndef upgrade():\n    ${upgrades if upgrades else "pass"}\n\ndef downgrade():\n    ${downgrades if downgrades else "pass"}\n'
-
+    ALEMBIC_INI_TEMPLATE = """[alembic]\nscript_location = {script_location}\nsqlalchemy.url = {sqlalchemy_url}\n"""
+    ALEMBIC_SCRIPT_TEMPLATE = '"""${message}"""\nfrom alembic import op\nimport sqlalchemy as sa\n\nrevision = ${repr(up_revision)}\ndown_revision = ${repr(down_revision)}\nbranch_labels = ${repr(branch_labels)}\ndepends_on = ${repr(depends_on)}\n\ndef upgrade():\n    ${upgrades if upgrades else "pass"}\n\n\ndef downgrade():\n    ${downgrades if downgrades else "pass"}\n'
 __all__ = [
     "DEFAULT_DB_ENV_VARS",
     "ASYNC_DRIVER_HINT",
